/**
 * Copyright (c) 2014-2015 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.clientserverapi.topology.exception;


/**
 * An error occurs attaching a container to a sub-domain.
 * 
 * @author Christophe DENEUX - Linagora
 */
public class AttachContainerException extends TopologyServiceException {

    private static final long serialVersionUID = 1771724545178817580L;

    private final static String MESSAGE_TEMPLATE = "Can't attach the current container to the sub-domain '%s' using the container '%s': %s";

    /**
     * Name of the sub-domain to attach to
     */
    private final String subdomainName;

    /**
     * Name of the container to used as entry point in the sub-domain
     */
    private final String containerName;

    public AttachContainerException(final String subdomainName, final String containerName, final String cause) {
        super(String.format(MESSAGE_TEMPLATE, subdomainName == null ? "not identified" : subdomainName, containerName,
                cause));
        this.subdomainName = subdomainName;
        this.containerName = containerName;
    }

    public AttachContainerException(final String subdomainName, final String containerName, final Throwable cause) {
        super(String.format(MESSAGE_TEMPLATE, subdomainName == null ? "not identified" : subdomainName, containerName,
                cause.getMessage()),
                cause);
        this.subdomainName = subdomainName;
        this.containerName = containerName;
    }

    /**
     * @return Name of the container to used as entry point in the sub-domain
     */
    public String getContainerName() {
        return this.containerName;
    }

    /**
     * @return Name of the sub-domain to attach to
     */
    public String getSubdomainName() {
        return subdomainName;
    }
    
}
