/**
 * Copyright (c) 2014-2015 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.clientserverapi.topology.exception;

/**
 * The sub-domain is not a <b>dynamic</b> sub-domain.
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public class SubdomainIsNotDynamicException extends TopologyServiceException {

    private static final long serialVersionUID = -3784973725731914909L;

    private static final String MESSAGE_PATTERN = "The sub-domain '%s' is not a dynamic sub-domain.";

    private static final String MESSAGE_PATTERN_CURRENT = "The current sub-domain is not a dynamic sub-domain.";
    
    /**
     * The name of the sub-domain that is not dynamic. If <code>null</code>, the sub-domain is the current one.
     */
    private final String subdomainName;

    public SubdomainIsNotDynamicException(final String subdomainName) {
        super(subdomainName == null ? MESSAGE_PATTERN_CURRENT : String.format(MESSAGE_PATTERN, subdomainName));
        this.subdomainName = subdomainName;
    }

    /**
     * @return The name of the sub-domain that is not dynamic. If <code>null</code>, the sub-domain is the current one.
     */
    public String getSubdomainName() {
        return this.subdomainName;
    }

}
